@@ -123,7 +123,7 @@ class SeriesAccessor(_SwifterObject):
                     .map_partitions(func, *args, meta=meta, **kwds)
                     .compute(scheduler=self._scheduler)
                 )
-        except (AssertionError, AttributeError, ValueError, TypeError):
+        except (AssertionError, AttributeError, ValueError, TypeError, KeyError):
             if self._progress_bar:
                 with TQDMDaskProgressBar(desc="Dask Apply"):
                     return (
@@ -160,6 +160,7 @@ class SeriesAccessor(_SwifterObject):
             ValueError,
             TypeError,
             TypingError,
+            KeyError,
         ):  # if can't vectorize, estimate time to pandas apply
             wrapped = self._wrapped_apply(func, convert_dtype=convert_dtype, args=args, **kwds)
             n_repeats = 3
@@ -218,7 +219,7 @@ class DataFrameAccessor(_SwifterObject):
                     .apply(func, *args, axis=axis, raw=raw, result_type=result_type, meta=meta, **kwds)
                     .compute(scheduler=self._scheduler)
                 )
-        except (AssertionError, AttributeError, ValueError, TypeError):
+        except (AssertionError, AttributeError, ValueError, TypeError, KeyError):
             if self._progress_bar:
                 tqdm.pandas(desc="Pandas Apply")
                 return self._obj.progress_apply(
@@ -263,6 +264,7 @@ class DataFrameAccessor(_SwifterObject):
             ValueError,
             TypeError,
             TypingError,
+            KeyError,
         ):  # if can't vectorize, estimate time to pandas apply
             wrapped = self._wrapped_apply(
                 func, axis=axis, broadcast=broadcast, raw=raw, reduce=reduce, result_type=result_type, args=args, **kwds
